/*
 * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
 * Copyright (C) $$Year-Rel$$ The Jalview Authors
 * 
 * This file is part of Jalview.
 * 
 * Jalview is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *  
 * Jalview is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty 
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 * PURPOSE.  See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
 * The Jalview Authors are detailed in the 'AUTHORS' file.
 */

package org.jalview;

import org.openjdk.jmh.annotations.Benchmark;
import org.openjdk.jmh.annotations.Setup;
import org.openjdk.jmh.annotations.State;
import org.openjdk.jmh.annotations.TearDown;
import org.openjdk.jmh.annotations.Scope;
import java.util.Random;

import jalview.datamodel.HiddenColumns;

/*
 * A class to benchmark hidden columns performance
 */
public class HiddenColumnsBenchmark 
{
	@State(Scope.Thread)
	public static class ThreadState
	{
		HiddenColumns h = new HiddenColumns();
		int MAXCOLS = 100000;
		Random rand = new Random();
	
		@Setup
		public void setup()
		{
			rand.setSeed(1234);
	    	for (int i=0; i<MAXCOLS; ++i)
	    	{
	    		int col = rand.nextInt(MAXCOLS); 
	    		h.hideColumns(col, col+1);
	    	}
		}
	
		@TearDown
		public void tearDown()
		{
			
		}
    }
	
	/*
	 * isVisible benchmarking
	 */
    @Benchmark
    public boolean benchIsVisibleLastCol(ThreadState tstate) 
    {
    	return tstate.h.isVisible(tstate.MAXCOLS - 3); 
    }
    
    @Benchmark
    public boolean benchIsVisibleFirstCol(ThreadState tstate)
    {
    	return tstate.h.isVisible(1);
    }

}
